/// 3d Application  
/// Starting 3d header file using the framework 
/// 
 
#pragma once 
 
/// base class to expanmd on later 
class CNew3dApp : public CD3DApplication 
{ 
public: 
 
	CNew3dApp(); 
 
 
	/// overrides for creating the app 
	/// provide default coverage for these fucntions 
 
	/// called first 
	virtual HRESULT OneTimeSceneInit(); 
	/// called next to initialize app objects 
	virtual HRESULT InitDeviceObjects(); 
	virtual HRESULT DeleteDeviceObjects(); 
	/// render the scene 
	virtual HRESULT Render(); 
	/// move the frame 
	virtual HRESULT FrameMove(); 
	/// called when device dependant objects are about to be lost 
	virtual HRESULT InvalidateDeviceObjects(); 
	/// renamed from restore surfaces in dx7 
	virtual HRESULT RestoreDeviceObjects(); 
	virtual HRESULT FinalCleanup(); 
 
 
	/// override the Messageproc from d3dapp 
	LRESULT MsgProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam ); 
 
 
	/// Store the Last HResult returned 
	inline void SetLastResult( HRESULT hResult ); 
	/// Get the Last hresult saved 
	inline HRESULT GetLastResult(); 
 
	/// store the current window instance 
	inline void SetInstance( HINSTANCE hInst ); 
	/// get the current instance 
	inline HINSTANCE GetInstance(); 
 
	/// set the window title 
	inline void SetWindowTitle( CString strWindowTitle ); 
	/// get the windowTitle 
	inline CString GetWindowTitle(); 
 
 
	/// switch on and off the showing of the stats 
	inline void SetShowStats( bool bStats ); 
	/// get the stats value 
	inline bool GetShowStats(); 
 
	/// switch on and off the 3d text in the stats 
	inline void Set3dText( bool bText ); 
	/// get the current 3d text value 
	inline bool Get3dText(); 
 
 
	virtual HRESULT Create( HINSTANCE hInst, TCHAR* szString ); 
 
	/// standard types for the format are D3DFMT_X8R8G8B8 ( 32 bit ), D3DFMT_R5G6B5 ( 16 bit ) and D3DFMT_R8G8B8 ( 24 bit )  
	/// ( my v5 card doesn't support 24 bit RGB Format at 800/600 ) 
	HRESULT SetScreenSize( int nHoriz, int nVert, BOOL bWindowed = FALSE, D3DFORMAT d3dFormat = D3DFMT_X8R8G8B8 ); 
 
 
private: 
 
	/// store the last value returned 
	HRESULT m_hLastResult; 
 
	/// Current window instance 
	HINSTANCE m_hiInstance; 
 
	/// show or hide the current stats 
	bool m_bShowStats; 
 
	/// Font class for drawing the current stats 
	CD3DFont *m_pFont; 
 
/// DEMO CODE 
	/// mesh object for demo 
	CD3DMesh *m_pObjectMesh; 
 
	/// d3d matrix for the world 
	D3DXMATRIX m_matWorld; 
	/// a d3dmatrix for positioning the object in 3d space 
	D3DXMATRIX    m_matObjectMatrix; 
	D3DXVECTOR3 m_vecEye; 
 
/// END DEMO CODE 
 
}; 
 
 
inline void CNew3dApp::SetLastResult( HRESULT hResult ) 
{ 
	m_hLastResult = hResult; 
} 
 
inline HRESULT CNew3dApp::GetLastResult() 
{ 
	return m_hLastResult; 
} 
 
inline void CNew3dApp::SetInstance( HINSTANCE hInstance ) 
{ 
	m_hiInstance = hInstance; 
} 
 
inline HINSTANCE CNew3dApp::GetInstance() 
{ 
	return m_hiInstance; 
} 
 
inline CString CNew3dApp::GetWindowTitle() 
{ 
	return m_strWindowTitle; 
} 
 
inline void CNew3dApp::SetWindowTitle( CString strWindowTitle ) 
{ 
	m_strWindowTitle = strWindowTitle.GetBuffer( 0 ); 
} 
 
inline void CNew3dApp::SetShowStats( bool bStats ) 
{ 
	m_bShowStats = bStats; 
} 
 
inline bool CNew3dApp::GetShowStats() 
{ 
	return m_bShowStats; 
} 
